@@ -27,6 +27,7 @@ class RFile;
 class RAction {
 protected:
     vec3 colour;
+    virtual void apply();
 public:
     RUser* source;
     RFile* target;
@@ -37,7 +38,8 @@ public:
     float rate;
 
     RAction(RUser* source, RFile* target, float addedtime);
-
+    virtual ~RAction() {};
+    
     inline bool isFinished() const { return (progress >= 1.0); };
 
     virtual void logic(float dt);
@@ -59,8 +61,12 @@ public:
 };
 
 class ModifyAction : public RAction {
+protected:
+    vec3 modify_colour;
 public:
-    ModifyAction(RUser* source, RFile* target, float addedtime);
+    ModifyAction(RUser* source, RFile* target, float addedtime, const vec3& modify_colour);
+
+    void apply();
 };
 
 #endif
