@@ -61,6 +61,7 @@ FXGlyph::FXGlyph(FXGlyphSet* set, unsigned int chr) {
 
     this->set = set;
     this->chr = chr;
+    this->ftglyph = 0;
 
     FT_Face ftface = set->getFTFace();
 
@@ -71,8 +72,6 @@ FXGlyph::FXGlyph(FXGlyphSet* set, unsigned int chr) {
     if(FT_Load_Glyph( ftface, index, FT_LOAD_DEFAULT ))
     throw FXFontException(ftface->family_name);
 
-    FT_Glyph ftglyph;
-
     if(FT_Get_Glyph( ftface->glyph, &ftglyph ))
         throw FXFontException(ftface->family_name);
 
@@ -96,6 +95,10 @@ FXGlyph::FXGlyph(FXGlyphSet* set, unsigned int chr) {
     page = 0;
 }
 
+FXGlyph::~FXGlyph() {
+    if(ftglyph!=0) FT_Done_Glyph(ftglyph);
+}
+
 void FXGlyph::setPage(FXGlyphPage* page, const vec4& texcoords) {
     this->page = page;
     this->texcoords = texcoords;
@@ -221,6 +224,11 @@ FXGlyphSet::~FXGlyphSet() {
         delete (*it);
     }
     pages.clear();
+
+    for(auto it: glyphs) {
+        delete it.second;
+    }
+    glyphs.clear();
 }
 
 void FXGlyphSet::init() {
