@@ -14,10 +14,9 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
-
+#include "sdlapp.h"
 #include "settings.h"
 #include "regex.h"
-
 #include "timezone.h"
 
 Regex SDLAppSettings_rect_regex("^([0-9.]+)x([0-9.]+)$");
@@ -32,6 +31,9 @@ SDLAppSettings::SDLAppSettings() {
     conf_sections["viewport"]           = "display";
     conf_sections["windowed"]           = "display";
     conf_sections["fullscreen"]         = "display";
+    conf_sections["frameless"]          = "display";
+    conf_sections["screen"]             = "display";
+    conf_sections["window-position"]    = "display";
     conf_sections["multi-sampling"]     = "display";
     conf_sections["output-ppm-stream"]  = "display";
     conf_sections["output-framerate"]   = "display";
@@ -47,7 +49,10 @@ SDLAppSettings::SDLAppSettings() {
     //boolean args
     arg_types["viewport"]          = "string";
     arg_types["windowed"]          = "bool";
+    arg_types["screen"]            = "int";
+    arg_types["window-position"]   = "string";
     arg_types["fullscreen"]        = "bool";
+    arg_types["frameless"]         = "bool";
     arg_types["transparent"]       = "bool";
     arg_types["multi-sampling"]    = "bool";
     arg_types["no-vsync"]          = "bool";
@@ -64,11 +69,17 @@ void SDLAppSettings::setDisplayDefaults() {
     display_height = 768;
 #endif
     fullscreen     = false;
+    frameless      = false;
     multisample    = false;
     transparent    = false;
     resizable      = true;
     vsync          = true;
 
+    screen = -1;
+
+    window_x = -1;
+    window_y = -1;
+
     output_ppm_filename = "";
     output_framerate    = 60;
 }
@@ -86,6 +97,20 @@ void SDLAppSettings::exportDisplaySettings(ConfFile& conf) {
 
     if(fullscreen)
         section->setEntry(new ConfEntry("fullscreen", fullscreen));
+    else {
+        if(frameless)
+            section->setEntry(new ConfEntry("frameless", frameless));
+
+        if(window_x >= 0 && window_y >= 0) {
+            char windowbuff[256];
+            snprintf(windowbuff, 256, "%dx%d", window_x, window_y);
+            section->setEntry(new ConfEntry("window-position", std::string(windowbuff)));
+        }
+    }
+
+    if(screen > 0) {
+        section->setEntry(new ConfEntry("screen", screen));
+    }
 
     if(multisample)
         section->setEntry(new ConfEntry("multi-sampling", multisample));
@@ -317,8 +342,6 @@ void SDLAppSettings::importDisplaySettings(ConfFile& conffile) {
 
         std::string viewport = entry->getString();
 
-
-
         int width  = 0;
         int height = 0;
         bool no_resize = false;
@@ -334,6 +357,22 @@ void SDLAppSettings::importDisplaySettings(ConfFile& conffile) {
         }
     }
 
+    if((entry = display_settings->getEntry("window-position")) != 0) {
+        std::string window_position = entry->getString();
+
+        if(!parseRectangle(window_position, window_x, window_y)) {
+            conffile.invalidValueException(entry);
+        }
+    }
+
+    if((entry = display_settings->getEntry("screen")) != 0) {
+        screen = entry->getInt();
+
+        if(screen < 1) {
+            conffile.invalidValueException(entry);
+        }
+    }
+
     if(display_settings->getBool("multi-sampling")) {
         multisample = true;
     }
@@ -346,6 +385,10 @@ void SDLAppSettings::importDisplaySettings(ConfFile& conffile) {
         fullscreen = false;
     }
 
+    if(display_settings->getBool("frameless") && !fullscreen) {
+        frameless = true;
+    }
+
     // default to use desktop resolution for fullscreen unless specified
     if(fullscreen && !viewport_specified) {
         display_width  = 0;
@@ -368,11 +411,6 @@ void SDLAppSettings::importDisplaySettings(ConfFile& conffile) {
 
         output_ppm_filename = entry->getString();
 
-#ifdef _WIN32
-        if(output_ppm_filename == "-") {
-            conffile.entryException(entry, "stdout PPM mode not supported on Windows");
-        }
-#endif
     }
 
     if((entry = display_settings->getEntry("output-framerate")) != 0) {
