@@ -96,9 +96,12 @@ public:
     int systemCommand(const std::string& command);
     void requireExecutable(const std::string& exename);
 
+    void bufferCommit(RCommit& commit);
+
     bool getCommitAt(float percent, RCommit& commit);
     bool findNextCommit(RCommit& commit, int attempts);
     bool nextCommit(RCommit& commit, bool validate = true);
+    bool hasBufferedCommit();
     bool isFinished();
     bool isSeekable();
     float getPercent();
