@@ -20,8 +20,6 @@
 
 #include "commitlog.h"
 
-std::string gGourceMercurialCommand();
-
 class MercurialLog : public RCommitLog {
 protected:
     bool parseCommit(RCommit& commit);
@@ -29,6 +27,8 @@ protected:
     BaseLog* generateLog(const std::string& dir);
 public:
     MercurialLog(const std::string& logfile);
+
+    static std::string logCommand();    
 };
 
 #endif
\ No newline at end of file
